SM2 class

Constructors

SM2()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decrypt(String cipher, String privateKey, {int cipherMode = C1C3C2}) String
解密
encrypt(String msg, String publicKey, {int cipherMode = C1C3C2}) String
加密 (C1 保留 04 前缀)
generateKeyPair() KeyPair
signature(String msg, String privateKey, {bool der = false, String userId = '1234567812345678'}) String
标准签名
verifySignature(String msg, String signHex, String publicKey, {bool der = false, String userId = '1234567812345678'}) bool
标准验签