SM4 class

Constructors

SM4()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decrypt(String cipherText, {String? key, SM4CryptoMode mode = SM4CryptoMode.ECB, String? iv}) String
encrypt(String plainText, {String? key, SM4CryptoMode mode = SM4CryptoMode.ECB, String? iv}) String
setKey(String key) → void

Constants

blockSize → const int
CK → const List<int>
FK → const List<int>
S_BOX → const List<int>
SM4_DECRYPT → const int
SM4_ENCRYPT → const int