ASN1Utils class

Constructors

ASN1Utils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodeDer(String input) Map<String, BigInt>
解析 ASN.1 der,针对 sm2 验签
encodeDer(BigInt r, BigInt s) String
ASN.1 der 编码,针对 sm2 签名