ECCurveFp class
Properties
- a ↔ ECFieldElementFp
-
getter/setter pair
- b ↔ ECFieldElementFp
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- infinity ↔ ECPointFp
-
getter/setter pair
- q → BigInt
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decodePointHex(
String s) → ECPointFp? -
equals(
Object? other) → bool -
fromBigInteger(
BigInt x) → ECFieldElementFp -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited