ECFieldElementFp class

Constructors

ECFieldElementFp(BigInt q, BigInt x)

Properties

hashCode int
The hash code for this object.
no setterinherited
q BigInt
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x BigInt
final

Methods

add(ECFieldElementFp b) ECFieldElementFp
相加
divide(ECFieldElementFp b) ECFieldElementFp
相除
equals(ECFieldElementFp other) bool
判断相等
multiply(ECFieldElementFp b) ECFieldElementFp
相乘
negate() ECFieldElementFp
取反
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
square() ECFieldElementFp
平方
subtract(ECFieldElementFp b) ECFieldElementFp
相减
toBigInteger() BigInt
返回具体数值
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited