ECPointFp class

Constructors

ECPointFp(ECCurveFp curve, ECFieldElementFp? x, ECFieldElementFp? y, [BigInt? z])

Properties

curve ECCurveFp
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x ECFieldElementFp?
latefinal
y ECFieldElementFp?
latefinal
z BigInt
latefinal
zinv BigInt?
getter/setter pair

Methods

add(ECPointFp b) ECPointFp
equals(ECPointFp other) bool
getX() ECFieldElementFp
getY() ECFieldElementFp
isInfinity() bool
multiply(BigInt k) ECPointFp
negate() ECPointFp
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
twice() ECPointFp

Operators

operator ==(Object other) bool
The equality operator.
inherited