SMUtils class

Constructors

SMUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bytesToHexString(List<int> bytes) String
hexStringToBytes(String hexString) List<int>
leftShift(int x, int n) int
rightShift(int x, int n) int
utf8ToHexString(String input) String